;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "show-eol" "20260101.602"
  "Show end of line symbol in buffer."
  '((emacs "24.4"))
  :url "https://github.com/jcs-elpa/show-eol"
  :commit "b484d2771f09666e2bccd0b19a8a1c9a1e16f614"
  :revdesc "b484d2771f09"
  :keywords '("convenience" "end" "eol" "line")
  :authors '(("Jen-Chieh" . "jcs090218@gmail.com"))
  :maintainers '(("Jen-Chieh" . "jcs090218@gmail.com")))
